@@ -731,6 +731,7 @@ class CdoTest(testClass):
       opCount = len(cdo.noOutputOperators)
       self.assertTrue(opCount > 50)
       self.assertTrue(opCount < 200)
+      self.assertTrue('verifygrid' in cdo.noOutputOperators)
 
     def test_operators_with_multiple_output_files(self):
       cdo = Cdo()
@@ -790,6 +791,38 @@ class CdoTest(testClass):
       cdo.cleanTempDir()
       self.assertEqual(0,len(os.listdir(tempPath)))
 
+    def testVerifyGrid(self):
+      cdo = Cdo()
+      output = cdo.verifygrid(input='-topo,global_10')
+      self.assertEqual([],output)
+
+      cdo.silent = False
+      output = cdo.verifygrid(input='-topo,global_10')
+      if parse_version('2.0.6') <= parse_version(cdo.version()):
+        expectedOutput = ['cdo    verifygrid: Grid consists of 648 (36x18) cells (type: lonlat), of which',
+                          'cdo    verifygrid:       648 cells have 4 vertices',
+                          'cdo    verifygrid:        72 cells have duplicate vertices',
+                          'cdo    verifygrid:        lon : -175 to 175 degrees',
+                          'cdo    verifygrid:        lat : -85 to 85 degrees']
+      elif parse_version('2.0.5') >= parse_version(cdo.version()) and parse_version('2.0.0') <= parse_version(cdo.version()):
+        expectedOutput = ['cdo(1) topo: Process started',
+                          'cdo    verifygrid: Grid consists of 648 (36x18) cells (type: lonlat), of which',
+                          'cdo    verifygrid:       648 cells have 4 vertices',
+                          'cdo    verifygrid:        72 cells have duplicate vertices',
+                          'cdo    verifygrid:        lon : -175 to 175 degrees',
+                          'cdo    verifygrid:        lat : -85 to 85 degrees',
+                          'cdo(1) topo:',
+                          'cdo    verifygrid: Processed 1 variable [0.00s 94MB].']
+      elif parse_version('2.0.0') > parse_version(cdo.version()):
+        # versions 1.9.x and earlier write to stderr and will not be tested
+        expectedOutput = []
+      else:
+        expectedOutput = []
+
+      self.assertEqual(expectedOutput,output)
+      cdo.silent = True
+
+
     if MAINTAINERMODE:
 
       def test_config(self):
@@ -930,7 +963,7 @@ class CdoTest(testClass):
         cdo = Cdo()
         cdo.debug = True
         if ('yeardiv' in cdo.operators):
-          input = "-expr,'seq=seq*cyear(seq)/seq;' -settaxis,2001-01-01,12:00:00,12hours -for,1,10000 -yearmean -expr,'seq=seq*cyear(seq)/seq;' -settaxis,2001-01-01,12:00:00,12hours -for,1,10000"
+          input = "-expr,'seq=seq*cyear()/seq;' -settaxis,2001-01-01,12:00:00,12hours -for,1,10000 -yearmean -expr,'seq=seq*cyear()/seq;' -settaxis,2001-01-01,12:00:00,12hours -for,1,10000"
           values = cdo.yeardiv(input=input,returnArray='seq')
           print(np.zeros(len(values))+1.0)
           print(np.ravel(values))
@@ -938,6 +971,16 @@ class CdoTest(testClass):
         else:
           print("no tests for 'yeardiv': operator does not exist")
 
+      # input operator does not work straight forward. the input needs to be set as output
+      def test_input_chain(self):
+        cdo       = Cdo()
+        cdo.debug = True
+        gridfile  = '/home/ram/Downloads/gridfile.txt'
+        inputfile = '/home/ram/Downloads/tmax.txt'
+        cdo.settaxis('1979-01-01,00:12:00,1days',
+            options = ' -r -f nc',
+            input = "-setname,tmax -setctomiss,-999.99 -input,{} tmax.nc < ".format(gridfile),
+            output = inputfile)
 #===============================================================================
 if __name__ == '__main__':
     suite = testLoader.loadTestsFromTestCase(CdoTest)
